%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                                                       %%
%%           Tunnel Face Stability Software              %%
%%                                                       %%
%%                     Main Program                      %%
%%                Version 1.0 ; July 2012                %%
%%                                                       %%
%%                Author: Guilhem Mollon                 %%
%%    Collaborators: Abdul-Hamid Soubra, Daniel Dias     %%
%%                                                       %%
%%   Realized at INSA Lyon, University of Lyon, France   %%
%%                   Years 2008-2010                     %%
%%                                                       %%
%%            Please read enclosed .txt file             %%
%%                                                       %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%% A. CHOICE OF THE TYPE OF COMPUTATION %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear
Type_Computation=12;

% Type 1:       Deterministic Collapse Pressure,        Frictional Soil
% Type 2:       Deterministic Collapse Safety Factor,   Frictional Soil
% Type 3:       Deterministic Blow-Out Pressure,        Frictional Soil
% Type 4:       Deterministic Blow-Out Safety Factor,   Frictional Soil
% Type 5:       Deterministic Collapse Pressure,        Non-Frictional Soil
% Type 6:       Deterministic Collapse Safety Factor,   Non-Frictional Soil
% Type 7:       Deterministic Blow-Out Pressure,        Non-Frictional Soil
% Type 8:       Deterministic Blow-Out Safety Factor,   Non-Frictional Soil
% Type 9:       Failure Probability by Collapse,        Frictional Soil
% Type 10:      Failure Probability by Blow-out,        Frictional Soil
% Type 11:      Failure Probability by Collapse,        Non-Frictional Soil
% Type 12:      Failure Probability by Blow-out,        Non-Frictional Soil



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%% B. DETERMINISTIC INPUT DATA %%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%% All Types %%%
Diam=11;            %Tunnel diameter (m)
Couv=14;            %Tunnel cover height / mean value if probabilistic (m)
Coh=38;             %Cohesion / mean value if probabilistic (kPa)
Qsurf=0;            %Ground surface pressure (kPa)
Gam=22;             %Unit weight / mean value if probabilistic (kN/m3)

%%% Types 1, 2, 3, and 4 %%%
Phi=21;             %Friction angle / mean value if probabilistic ()
Ntet=200;           %Radial discretization (multiple of 4)
Delta_Beta=1;       %Axial discretization ()

%%% Types 5, 6, 7, and 8 %%%
Nteta=90;           %Axial discretization
Nr=100;             %Radial discretization
Nbeta=90;           %Orthoradial discretization

%%% Types 2, 4, 6, and 8 %%%
SigT=100;           %Applied face pressure / mean value if probabilistic (kPa)



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%% C. PROBABILISTIC INPUT DATA %%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

COVPhi=12;          %COV of the friction angle (%)
LawPhi=1;           %Statistical law of the friction angle (0->Normal ; 1->Beta)
PhiMin=0;           %Lower bound of the friction angle (if Beta law) ()
PhiMax=45;          %Upper bound of the friction angle (if Beta law) ()

COVCoh=25;          %COV of the cohesion (%)
LawCoh=1;           %Statistical law of the cohesion (0->Normal ; 1->Lognormal)

Correl=-0.3;        %Correlation between friction angle and cohesion

COVGam=5;           %COV of the unit weight (%)
LawGam=1;           %Statistical law of the unit weight (0->Normal ; 1->Lognormal)

COVCouv=5;          %COV of the cover height (%)
LawCouv=1;          %Statistical law of the cover height (0->Normal ; 1->Lognormal)

MinSigT=100;        %Lower bound of the desired interval of prescribed face pressures
MaxSigT=800;        %Upper bound of the desired interval of prescribed face pressures
InterSigT=20;       %Increment of the desired interval of prescribed face pressures
COVSigT=15;         %COV of the applied face pressure (%)
LawSigT=1;          %Statistical law of the applied face pressure (0->Normal ; 1->Lognormal)



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%% D. PROBABILISTIC SOLVING PARAMETERS %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Ordre=3;            % PCE Order
Nsample=1000000;    % Number of Monte-Carlo samples for computing CDF/PDF.
Interval=1;         % Width of the histogram intervals
Min=0;              % Lower bound of the first interval
Max=1000;           % Upper bound of the last interval
h=5;                % Bandwidth for the Kernel Smoothing
N_MC=1000000;       % Number of Monte-Carlo samples for failure probability computation



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%% E. COMPUTATIONS %%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%     PRESS F5    %%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[Optimum_SigmaC,Optimum_SigmaB,Optimum_Beta,Optimum_R,Safety_Factor,PhySpace,Donnees,Courbes,MomentsMC,MomentsAN,Sobol,SigT_MC,Pf_MC,COV_MC]=Secondary_Program(Type_Computation,Diam,Couv,Coh,Qsurf,Gam,Phi,Ntet,Delta_Beta,Nteta,Nr,Nbeta,SigT,COVPhi,LawPhi,PhiMin,PhiMax,COVCoh,LawCoh,Correl,COVGam,LawGam,COVCouv,LawCouv,MinSigT,MaxSigT,InterSigT,COVSigT,LawSigT,Ordre,Nsample,Interval,Min,Max,h,N_MC);